==> IOUSBFamily-258.4.1.tar.gz: IOUSBFamily-258.4.1/AppleUSBUHCI/Headers/AppleUHCIqhMemoryBlock.h <==
/*
 *
 * @APPLE_LICENSE_HEADER_START@
 * 
 * Copyright (c) 1998-2003 Apple Computer, Inc.  All Rights Reserved.
 * 
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this
 * file.
 * 
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 * 
 * @APPLE_LICENSE_HEADER_END@
 */


#ifndef _IOKIT_AppleUHCIqhMemoryBlock_H
#define _IOKIT_AppleUHCIqhMemoryBlock_H

#include <IOKit/IOBufferMemoryDescriptor.h>

#include "AppleUSBUHCI.h"
#include "UHCI.h"


class AppleUHCIqhMemoryBlock : public IOBufferMemoryDescriptor
{
    OSDeclareDefaultStructors(AppleUHCIqhMemoryBlock);
    
#define QHsPerBlock	(kUHCIPageSize / sizeof(UHCIQueueHeadShared))
	
private:
    IOPhysicalAddress							_sharedPhysical;
    UHCIQueueHeadSharedPtr						_sharedLogical;
    AppleUHCIqhMemoryBlock						*_nextBlock;
    
public:
		
    static AppleUHCIqhMemoryBlock				*NewMemoryBlock(void);
    void										SetNextBlock(AppleUHCIqhMemoryBlock *next);
    AppleUHCIqhMemoryBlock						*GetNextBlock(void);
    UInt32										NumQHs(void);
    IOPhysicalAddress							GetPhysicalPtr(UInt32 index);
    UHCIQueueHeadSharedPtr						GetLogicalPtr(UInt32 index);
};


#endif

==> IOUSBFamily-261.4.2.tar.gz: IOUSBFamily-261.4.2/AppleUSBUHCI/Headers/AppleUHCIqhMemoryBlock.h <==
/*
 *
 * @APPLE_LICENSE_HEADER_START@
 * 
 * Copyright (c) 1998-2003 Apple Computer, Inc.  All Rights Reserved.
 * 
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this
 * file.
 * 
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 * 
 * @APPLE_LICENSE_HEADER_END@
 */


#ifndef _IOKIT_AppleUHCIqhMemoryBlock_H
#define _IOKIT_AppleUHCIqhMemoryBlock_H

#include <IOKit/IOBufferMemoryDescriptor.h>

#include "AppleUSBUHCI.h"
#include "UHCI.h"


class AppleUHCIqhMemoryBlock : public OSObject
{
    OSDeclareDefaultStructors(AppleUHCIqhMemoryBlock);
    
#define QHsPerBlock	(kUHCIPageSize / sizeof(UHCIQueueHeadShared))
	
private:
    IOPhysicalAddress							_sharedPhysical;
    UHCIQueueHeadSharedPtr						_sharedLogical;
    AppleUHCIqhMemoryBlock						*_nextBlock;
	IOBufferMemoryDescriptor					*_buffer;
    
public:
		
    static AppleUHCIqhMemoryBlock				*NewMemoryBlock(void);
    void										SetNextBlock(AppleUHCIqhMemoryBlock *next);
    AppleUHCIqhMemoryBlock						*GetNextBlock(void);
    UInt32										NumQHs(void);
    IOPhysicalAddress							GetPhysicalPtr(UInt32 index);
    UHCIQueueHeadSharedPtr						GetLogicalPtr(UInt32 index);
};


#endif
